/*
IButton is a regular push button except that it accepts images instead
of text--IButton is short for Image Button.
*/
package extra.ui;

import waba.ui.*;
import waba.fx.*;
import waba.sys.Vm;

/**
* Button is a push button control.
 * <p>
 * Here is an example showing a push button being used:
 *
 * <pre>
 * public class MyProgram extends MainWindow
 * {
 * IButton pushB;
 *
 * public void onStart()
 *  {
 *  Image img = new Image("image.bmp");
 *  pushB = new IButton(img);
 *  pushB.setRect(10, 10, 80, 30);
 *  add(pushB);
 *  }
 *
 * public void onEvent(Event event)
 *  {
 *  if (event.type == ControlEvent.PRESSED &&
 *      event.target == pushB)
 *   {
 *   ... handle pushB being pressed
 * </pre>
 */

public class IButton extends Control
{
Image picture;
Font font;
boolean armed;

/** Creates a button displaying the given text. */
public IButton(Image picture)
	{
	this.picture = picture;
	}

/** Sets the text that is displayed in the button. */
public void setPicture(Image picture)
	{
	this.picture = picture;
	repaint();
	}

/** Called by the system to pass events to the button. */
public void onEvent(Event event)
	{
	if (event.type == PenEvent.PEN_DOWN)
		{
		armed = true;
		repaint();
		}
	else if (event.type == PenEvent.PEN_UP)
		{
		armed = false;
		repaint();
		PenEvent pe = (PenEvent)event;
		if (pe.x >= 0 && pe.x < this.width && pe.y >= 0 && pe.y < this.height)
			postEvent(new ControlEvent(ControlEvent.PRESSED, this));
		}
	else if (event.type == PenEvent.PEN_DRAG)
		{
		PenEvent pe = (PenEvent)event;
		boolean lArmed = false;
		if (pe.x >= 0 && pe.x < this.width && pe.y >= 0 && pe.y < this.height)
			lArmed = true;
		if (armed != lArmed)
			{
			armed = lArmed;
			repaint();
			}
		}
	}

public static void drawButton(Graphics g, boolean armed, int width, int height)
	{
	boolean isColor = Vm.isColor();
	int x2 = width - 1;
	int y2 = height - 1;
	if (!isColor)
		{
		// draw top, bottom, left and right lines
		g.setColor(0, 0, 0);
		g.drawLine(3, 0, x2 - 3, 0);
		g.drawLine(3, y2, x2 - 3, y2);
		g.drawLine(0, 3, 0, y2 - 3);
		g.drawLine(x2, 3, x2, y2 - 3);

		if (armed)
			g.fillRect(1, 1, width - 2, height - 2);
		else
			{
			// draw corners (tl, tr, bl, br)
			g.drawLine(1, 1, 2, 1);
			g.drawLine(x2 - 2, 1, x2 - 1, 1);
			g.drawLine(1, y2 - 1, 2, y2 - 1);
			g.drawLine(x2 - 2, y2 - 1, x2 - 1, y2 - 1);

			// draw corner dots
			g.drawLine(1, 2, 1, 2);
			g.drawLine(x2 - 1, 2, x2 - 1, 2);
			g.drawLine(1, y2 - 2, 1, y2 - 2);
			g.drawLine(x2 - 1, y2 - 2, x2 - 1, y2 - 2);
			}

		}
	else
		{
		// top, left
		if (armed)
			g.setColor(0, 0, 0);
		else
			g.setColor(255, 255, 255);
		g.drawLine(0, 0, x2 - 1, 0);
		g.drawLine(0, 0, 0, y2 - 1);

		// top, left shadow
		if (armed)
			{
			g.setColor(130, 130, 130);
			g.drawLine(1, 1, x2 - 1, 1);
			g.drawLine(1, 1, 1, y2 - 1);
			}

		// bottom, right
		if (armed)
			g.setColor(255, 255, 255);
		else
			g.setColor(0, 0, 0);
		g.drawLine(0, y2, x2, y2);
		g.drawLine(x2, y2, x2, 0);

		// bottom, right shadow
		if (!armed)
			{
			g.setColor(130, 130, 130);
			g.drawLine(1, y2 - 1, x2 - 1, y2 - 1);
			g.drawLine(x2 - 1, y2 - 1, x2 - 1, 1);
			}
		}
	}

/** Called by the system to draw the button. */
public void onPaint(Graphics g)
	{
	drawButton(g, armed, this.width, this.height);

	// draw label
	if (armed && !Vm.isColor())
		g.setColor(255, 255, 255);
	else
		g.setColor(0, 0, 0);
	int x = (this.width - picture.getWidth()) / 2;
	int y = (this.height - picture.getHeight()) / 2;
	if (armed)
		{
		x++;
		y++;
		}
	g.drawImage(picture, x, y);
	}
}
